# CLI Reference

Command-line tools for OneTool.

| CLI | Description |
|-----|-------------|
| [**onetool**](onetool.md) | Start the OneTool MCP server |
| [**onetool direct**](onetool-direct.md) | Run tools from the shell, manage the execution server, or launch the REPL |
